import React, { useState } from 'react'
import { useDrop } from 'react-dnd'
import { Icon, Button } from 'antd'
import update from 'immutability-helper'
import Card from './card'
import ItemTypes from './itemtypes'
import './index.scss'

const Container = ({dict, list, handlePreviewList, handleMenu, handleButton }) => {
  const [cards, setCards] = useState(list)
  const moveCard = (id, atIndex) => {
    const { card, index } = findCard(id)
    const _cards = update(cards, { $splice: [[index, 1], [atIndex, 0, card]] })
    setCards(_cards)
    handlePreviewList(_cards)
  }

  const findCard = id => {
    const card = cards.filter(c => `${c.id}` === id)[0]
    return {
      card,
      index: cards.indexOf(card),
    }
  }

  const editCard = id => {
    const { card, index } = findCard(id)
    handleMenu({
      card,
      index,
      type: 'edit'
    })
  }

  const add = () => {
    handleButton('add')
  }
  
  const confirm = () => {
    handleButton('confirm')
  }

  const cancel = () => {
    handleButton('cancel')
  }

  const thawmenu = () => {
    handleButton('thawmenu')
  }

  const [, drop] = useDrop({ accept: ItemTypes.CARD })
  return (
    <div ref={drop} className="dragdashboard">
      {cards.map(card => (
        <Card
          key={card.id}
          id={`${card.id}`}
          text={card.text}
          moveCard={moveCard}
          editCard={editCard}
          findCard={findCard}
        />
      ))}
      <div className="btn-group">
        <div className="card-add" onClick={add}>
          <Icon type="plus" />
        </div>
        <Button type="primary" onClick={thawmenu}>{dict['header.thawmenu']}</Button>
        <Button type="primary" onClick={confirm}>{dict['header.confirm']}</Button>
        <Button onClick={cancel}>{dict['header.close']}</Button>
      </div>
    </div>
  )
}
export default Container
